==> inte_auth-0.1.0-py3-none-any.whl: inte_auth/codenames/clinic.py <==
from edc_auth.codenames import clinic

clinic += [
    "inte_lists.view_arvregimens",
    "inte_lists.view_conditions",
    "inte_lists.view_diabetestreatment",
    "inte_lists.view_hypertensiontreatment",
    "inte_lists.view_offstudyreasons",
    "inte_prn.add_endofstudy",
    "inte_prn.add_losstofollowup",
    "inte_prn.add_onschedule",
    "inte_prn.add_protocoldeviationviolation",
    "inte_prn.change_endofstudy",
    "inte_prn.change_losstofollowup",
    "inte_prn.change_onschedule",
    "inte_prn.change_protocoldeviationviolation",
    "inte_prn.delete_endofstudy",
    "inte_prn.delete_losstofollowup",
    "inte_prn.delete_onschedule",
    "inte_prn.delete_protocoldeviationviolation",
    "inte_prn.view_endofstudy",
    "inte_prn.view_historicalendofstudy",
    "inte_prn.view_historicallosstofollowup",
    "inte_prn.view_historicalonschedule",
    "inte_prn.view_historicalprotocoldeviationviolation",
    "inte_prn.view_losstofollowup",
    "inte_prn.view_onschedule",
    "inte_prn.view_protocoldeviationviolation",
    "inte_prn.view_unblindingrequestoruser",
    "inte_prn.view_unblindingrevieweruser",
    "inte_subject.add_anthropometry",
    "inte_subject.add_diabetesinitialreview",
    "inte_subject.add_generalassessment",
    "inte_subject.add_generalassessmentinitial",
    "inte_subject.add_healtheconomics",
    "inte_subject.add_hivinitialreview",
    "inte_subject.add_hypertensioninitialreview",
    "inte_subject.add_physicalactivity",
    "inte_subject.add_riskfactors",
    "inte_subject.add_subjectrequisition",
    "inte_subject.add_subjectvisit",
    "inte_subject.change_anthropometry",
    "inte_subject.change_diabetesinitialreview",
    "inte_subject.change_generalassessment",
    "inte_subject.change_generalassessmentinitial",
    "inte_subject.change_healtheconomics",
    "inte_subject.change_hivinitialreview",
    "inte_subject.change_hypertensioninitialreview",
    "inte_subject.change_physicalactivity",
    "inte_subject.change_riskfactors",
    "inte_subject.change_subjectrequisition",
    "inte_subject.change_subjectvisit",
    "inte_subject.delete_anthropometryinitial",
    "inte_subject.delete_diabetesinitialreview",
    "inte_subject.delete_generalassessment",
    "inte_subject.delete_generalassessmentinitial",
    "inte_subject.delete_healtheconomics",
    "inte_subject.delete_hivinitialreview",
    "inte_subject.delete_hypertensioninitialreview",
    "inte_subject.delete_physicalactivity",
    "inte_subject.delete_riskfactors",
    "inte_subject.delete_subjectrequisition",
    "inte_subject.delete_subjectvisit",
    "inte_subject.view_anthropometry",
    "inte_subject.view_diabetesinitialreview",
    "inte_subject.view_generalassessment",
    "inte_subject.view_generalassessmentinitial",
    "inte_subject.view_healtheconomics",
    "inte_subject.view_historicalanthropometry",
    "inte_subject.view_historicaldiabetesinitialreview",
    "inte_subject.view_historicalgeneralassessment",
    "inte_subject.view_historicalgeneralassessmentinitial",
    "inte_subject.view_historicalhealtheconomics",
    "inte_subject.view_historicalhivinitialreview",
    "inte_subject.view_historicalhypertensioninitialreview",
    "inte_subject.view_historicalphysicalactivity",
    "inte_subject.view_historicalriskfactors",
    "inte_subject.view_historicalsubjectrequisition",
    "inte_subject.view_historicalsubjectvisit",
    "inte_subject.view_hivinitialreview",
    "inte_subject.view_hypertensioninitialreview",
    "inte_subject.view_physicalactivity",
    "inte_subject.view_riskfactors",
    "inte_subject.view_subjectrequisition",
    "inte_subject.view_subjectvisit",
]
clinic.sort()

==> inte_auth-0.1.1-py3-none-any.whl: inte_auth/codenames/clinic.py <==
from edc_auth.codenames import clinic

clinic += [
    "inte_lists.view_arvregimens",
    "inte_lists.view_conditions",
    "inte_lists.view_diabetestreatment",
    "inte_lists.view_hypertensiontreatment",
    "inte_lists.view_offstudyreasons",
    "inte_prn.add_endofstudy",
    "inte_prn.add_losstofollowup",
    "inte_prn.add_onschedule",
    "inte_prn.add_protocoldeviationviolation",
    "inte_prn.change_endofstudy",
    "inte_prn.change_losstofollowup",
    "inte_prn.change_onschedule",
    "inte_prn.change_protocoldeviationviolation",
    "inte_prn.delete_endofstudy",
    "inte_prn.delete_losstofollowup",
    "inte_prn.delete_onschedule",
    "inte_prn.delete_protocoldeviationviolation",
    "inte_prn.view_endofstudy",
    "inte_prn.view_historicalendofstudy",
    "inte_prn.view_historicallosstofollowup",
    "inte_prn.view_historicalonschedule",
    "inte_prn.view_historicalprotocoldeviationviolation",
    "inte_prn.view_losstofollowup",
    "inte_prn.view_onschedule",
    "inte_prn.view_protocoldeviationviolation",
    "inte_prn.view_unblindingrequestoruser",
    "inte_prn.view_unblindingrevieweruser",
    "inte_subject.add_anthropometry",
    "inte_subject.add_diabetesinitialreview",
    "inte_subject.add_generalassessment",
    "inte_subject.add_generalassessmentinitial",
    "inte_subject.add_healtheconomics",
    "inte_subject.add_hivinitialreview",
    "inte_subject.add_hypertensioninitialreview",
    "inte_subject.add_physicalactivity",
    "inte_subject.add_riskfactors",
    "inte_subject.add_subjectrequisition",
    "inte_subject.add_subjectvisit",
    "inte_subject.change_anthropometry",
    "inte_subject.change_diabetesinitialreview",
    "inte_subject.change_generalassessment",
    "inte_subject.change_generalassessmentinitial",
    "inte_subject.change_healtheconomics",
    "inte_subject.change_hivinitialreview",
    "inte_subject.change_hypertensioninitialreview",
    "inte_subject.change_physicalactivity",
    "inte_subject.change_riskfactors",
    "inte_subject.change_subjectrequisition",
    "inte_subject.change_subjectvisit",
    "inte_subject.delete_anthropometry",
    "inte_subject.delete_diabetesinitialreview",
    "inte_subject.delete_generalassessment",
    "inte_subject.delete_generalassessmentinitial",
    "inte_subject.delete_healtheconomics",
    "inte_subject.delete_hivinitialreview",
    "inte_subject.delete_hypertensioninitialreview",
    "inte_subject.delete_physicalactivity",
    "inte_subject.delete_riskfactors",
    "inte_subject.delete_subjectrequisition",
    "inte_subject.delete_subjectvisit",
    "inte_subject.view_anthropometry",
    "inte_subject.view_diabetesinitialreview",
    "inte_subject.view_generalassessment",
    "inte_subject.view_generalassessmentinitial",
    "inte_subject.view_healtheconomics",
    "inte_subject.view_historicalanthropometry",
    "inte_subject.view_historicaldiabetesinitialreview",
    "inte_subject.view_historicalgeneralassessment",
    "inte_subject.view_historicalgeneralassessmentinitial",
    "inte_subject.view_historicalhealtheconomics",
    "inte_subject.view_historicalhivinitialreview",
    "inte_subject.view_historicalhypertensioninitialreview",
    "inte_subject.view_historicalphysicalactivity",
    "inte_subject.view_historicalriskfactors",
    "inte_subject.view_historicalsubjectrequisition",
    "inte_subject.view_historicalsubjectvisit",
    "inte_subject.view_hivinitialreview",
    "inte_subject.view_hypertensioninitialreview",
    "inte_subject.view_physicalactivity",
    "inte_subject.view_riskfactors",
    "inte_subject.view_subjectrequisition",
    "inte_subject.view_subjectvisit",
]
clinic.sort()
